@@ -5,7 +5,7 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2005 
+   Copyright (C) 2005, 2006, 2007, 2008
    Gerber van der Graaf <gerber_graaf@users.sourceforge.net>
 
    This file is part of gpiv.
@@ -29,6 +29,9 @@
 /*
  * functions for dac_cam
  * $Log: dac_cam.c,v $
+ * Revision 1.7  2008-04-28 12:00:57  gerber
+ * hdf-formatted files are now with .hdf extension (previously: .gpi)
+ *
  * Revision 1.6  2007-12-19 08:42:35  gerber
  * debugged
  *
@@ -152,33 +155,33 @@ exec_cam_start(GpivConsole * gpiv
  * report camera's feature set
  * in: on_menu_camera_select
  */
-/*         dc1394_print_feature_set(&cam_var.feature_set[0]); */
+/*         dc1394_print_feature_set(&cam_var->feature_set[0]); */
 
 /*    g_message("exec_cam_start:: mode[%d] = %s", */
-/*              cam_var.misc_info[0].mode, */
-/*              format0_desc[cam_var.misc_info[0].mode - MODE_FORMAT0_MIN]); */
+/*              cam_var->misc_info[0].mode, */
+/*              format0_desc[cam_var->misc_info[0].mode - MODE_FORMAT0_MIN]); */
 /*    g_message("exec_cam_start:: format[%d] = %s", */
-/*              cam_var.misc_info[0].format,  */
-/*              format_desc[cam_var.misc_info[0].format - FORMAT_MIN]); */
+/*              cam_var->misc_info[0].format,  */
+/*              format_desc[cam_var->misc_info[0].format - FORMAT_MIN]); */
 
-   if (verbose) g_warning("exec_cam_start:: fps = %d", cam_var.misc_info[0].framerate/*  - FRAMERATE_MIN */);
-    if (dc1394_setup_capture(cam_var.camera[0].handle, 
-                             cam_var.camera[0].id, 
-                             cam_var.misc_info[0].iso_channel, 
-                             cam_var.misc_info[0].format, 
-                             cam_var.misc_info[0].mode, 
-                             cam_var.maxspeed,
+    if (verbose) g_warning("exec_cam_start:: fps = %d", cam_var->misc_info[0].framerate/*  - FRAMERATE_MIN */);
+    if (dc1394_setup_capture(cam_var->camera[0].handle, 
+                             cam_var->camera[0].id, 
+                             cam_var->misc_info[0].iso_channel, 
+                             cam_var->misc_info[0].format, 
+                             cam_var->misc_info[0].mode, 
+                             cam_var->maxspeed,
 
-                             cam_var.misc_info[0].framerate, 
+                             cam_var->misc_info[0].framerate, 
 
 /*                              FRAMERATE_7_5,   */
 
 /* FRAMERATE_3_75, */
 
-                             &cam_var.capture[0])
+                             &cam_var->capture[0])
         != DC1394_SUCCESS) {
-        dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);
-        raw1394_destroy_handle(cam_var.handle);
+        dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);
+        raw1394_destroy_handle(cam_var->handle);
         warning_gpiv(_("Unable to setup camera-\n\
 check line %d of %s to make sure\n\
 that the video mode,framerate and format are\n\
@@ -191,10 +194,10 @@ supported by your camera"),
 /*
  * have the camera start sending us data
  */
-    if (dc1394_start_iso_transmission(cam_var.handle, cam_var.capture[0].node) 
+    if (dc1394_start_iso_transmission(cam_var->handle, cam_var->capture[0].node) 
         != DC1394_SUCCESS) {
-        dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);
-        raw1394_destroy_handle(cam_var.handle);
+        dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);
+        raw1394_destroy_handle(cam_var->handle);
         warning_gpiv(_("Unable to start camera iso transmission"));
         return;
     }
@@ -211,10 +214,10 @@ supported by your camera"),
  * set trigger mode and use triggering or just free run
  */
     
-    if (gpiv_par.console__trigger_cam) {
+    if (gpiv_par->console__trigger_cam) {
         if (verbose) g_warning("exec_cam_start:: trigger_cam");
-/*             if (dc1394_set_trigger_mode(cam_var.handle,  */
-/*                                         cam_var.capture[0].node,  */
+/*             if (dc1394_set_trigger_mode(cam_var->handle,  */
+/*                                         cam_var->capture[0].node,  */
 /*                                         TRIGGER_MODE_0) != DC1394_SUCCESS) */
 /*                 { */
 /*                     warning_gpiv(_("unable to set camera trigger mode")); */
@@ -236,15 +239,15 @@ supported by your camera"),
  * Stop data transmission
  */
         if (verbose) g_warning("exec_cam_start:: Stop data transmission and release camera");
-    if (dc1394_stop_iso_transmission(cam_var.handle, cam_var.capture[0].node)
+    if (dc1394_stop_iso_transmission(cam_var->handle, cam_var->capture[0].node)
         != DC1394_SUCCESS
-/*         && dc1394_release_camera(cam_var.handle, &cam_var.capture[0])   */
+/*         && dc1394_release_camera(cam_var->handle, &cam_var->capture[0])   */
 /*         != DC1394_SUCCESS  */
         ) {
         warning_gpiv(_("couldn't stop the camera?"));
     }
-/* in: exec_stop_cam    dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);     */
-/*in: exec_stop_cam:    raw1394_destroy_handle(cam_var.handle); */
+/* in: exec_stop_cam    dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);     */
+/*in: exec_stop_cam:    raw1394_destroy_handle(cam_var->handle); */
 
 }
 
@@ -258,18 +261,18 @@ exec_cam_stop (void
     gint i;
 
     cancel_process = TRUE;
-    for (i = 0; i < cam_var.numCameras; i++) { 
-        if (dc1394_stop_iso_transmission(cam_var.handle, cam_var.capture[i].node)
+    for (i = 0; i < cam_var->numCameras; i++) { 
+        if (dc1394_stop_iso_transmission(cam_var->handle, cam_var->capture[i].node)
             != DC1394_SUCCESS) 
             {
                 warning_gpiv(_("couldn't stop the camera?"));
             }
         
         pthread_exit(NULL);
-        dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);
+        dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);
     }
-    if (cam_var.numCameras > 0) {
-        raw1394_destroy_handle(cam_var.handle);
+    if (cam_var->numCameras > 0) {
+        raw1394_destroy_handle(cam_var->handle);
     }
 }
 
@@ -302,15 +305,15 @@ on_menu_format (GtkWidget *widget,
 /*   IsoFlowCheck(state); */
 
        if (verbose) g_message("on_menu_format:: ");
-    if (!dc1394_get_iso_status(cam_var.camera[0].handle, cam_var.camera[0].id, 
-                               &cam_var.misc_info[0].is_iso_on)) {
+    if (!dc1394_get_iso_status(cam_var->camera[0].handle, cam_var->camera[0].id, 
+                               &cam_var->misc_info[0].is_iso_on)) {
         g_warning("Cannot get ISO status");
     } else {
-        if (cam_var.misc_info[0].is_iso_on > 0) {
+        if (cam_var->misc_info[0].is_iso_on > 0) {
             cancel_process = TRUE;
         }
     }
-    was_iso_on = cam_var.misc_info[0].is_iso_on;
+    was_iso_on = cam_var->misc_info[0].is_iso_on;
 /*        g_message("on_menu_format:: is_iso_on = %d", was_iso_on); */
 
 
@@ -337,20 +340,20 @@ on_menu_format (GtkWidget *widget,
         warning_gpiv(_("on_menu_format: non valid format"));
     }
 
-    if (!dc1394_set_video_format(cam_var.camera[0].handle, 
-                                 cam_var.camera[0].id,
+    if (!dc1394_set_video_format(cam_var->camera[0].handle, 
+                                 cam_var->camera[0].id,
                                  format)) {
         if (verbose) g_warning("on_menu_format:: Could not set video format");
     } else {
-        cam_var.misc_info[0].format = format;
+        cam_var->misc_info[0].format = format;
     }
 
-    if (!dc1394_set_video_mode(cam_var.camera[0].handle,
-                               cam_var.camera[0].id,
+    if (!dc1394_set_video_mode(cam_var->camera[0].handle,
+                               cam_var->camera[0].id,
                                mode)) {
         if (verbose) g_warning("on_menu_format:: Could not set video format");
     } else {
-        cam_var.misc_info[0].mode = mode;
+        cam_var->misc_info[0].mode = mode;
     }
 
 
@@ -383,9 +386,9 @@ on_menu_fps (GtkWidget *widget,
 /* ----------------------------------------------------------------------------
  */
 {
-    cam_var.misc_info[0].framerate = (int) data/*  - FRAMERATE_MIN */;
-/* cam_var.misc_info[0].framerat */
-    if (verbose) g_warning("on_menu_fps:: fps = %d", cam_var.misc_info[0].framerate);
+    cam_var->misc_info[0].framerate = (int) data/*  - FRAMERATE_MIN */;
+/* cam_var->misc_info[0].framerat */
+    if (verbose) g_warning("on_menu_fps:: fps = %d", cam_var->misc_info[0].framerate);
 }
 
 
@@ -398,12 +401,12 @@ on_trigger_polarity_toggled            (GtkToggleButton *togglebutton,
 {
 /* ----------------------------------------------------------------------------
  */
-  if (!dc1394_set_trigger_polarity(cam_var.camera[0].handle,
-                                   cam_var.camera[0].id,
+  if (!dc1394_set_trigger_polarity(cam_var->camera[0].handle,
+                                   cam_var->camera[0].id,
                                    togglebutton->active)) {
       message_gpiv(_("Cannot set trigger polarity"));
   } else {
-      cam_var.feature_set[0].feature[FEATURE_TRIGGER-FEATURE_MIN].
+      cam_var->feature_set[0].feature[FEATURE_TRIGGER-FEATURE_MIN].
           trigger_polarity = (int) togglebutton->active;
   }
 }
@@ -416,13 +419,13 @@ on_trigger_external_toggled            (GtkToggleButton *togglebutton,
 {
 /* ----------------------------------------------------------------------------
  */
-  if (!dc1394_feature_on_off(cam_var.camera[0].handle, 
-                             cam_var.camera[0].id, 
+  if (!dc1394_feature_on_off(cam_var->camera[0].handle, 
+                             cam_var->camera[0].id, 
                              FEATURE_TRIGGER, 
                              togglebutton->active)) {
       message_gpiv(_("Cannot set external trigger source"));
   } else {
-      cam_var.feature_set[0].feature[FEATURE_TRIGGER - FEATURE_MIN].is_on =
+      cam_var->feature_set[0].feature[FEATURE_TRIGGER - FEATURE_MIN].is_on =
           togglebutton->active;
   }
 /*   UpdateTriggerFrame(); */
@@ -436,11 +439,11 @@ on_trigger_mode_activate (GtkWidget *widget,
 /* ----------------------------------------------------------------------------
  */
 {
-  if (!dc1394_set_trigger_mode(cam_var.camera[0].handle, cam_var.camera[0].id,
+  if (!dc1394_set_trigger_mode(cam_var->camera[0].handle, cam_var->camera[0].id,
                                (int) user_data)) {
       message_gpiv(_("Cannot set trigger mode"));
   } else {
-      cam_var.feature_set[0].feature[FEATURE_TRIGGER-FEATURE_MIN].
+      cam_var->feature_set[0].feature[FEATURE_TRIGGER-FEATURE_MIN].
           trigger_mode = (int) user_data;
   }
 
@@ -453,11 +456,11 @@ on_trigger_mode_activate (GtkWidget *widget,
 /* on_trigger_value_changed               (GtkAdjustment    *adj, */
 /*                                         gpointer         user_data) */
 /* { */
-/*   if (!dc1394_set_feature_value(cam_var.camera[0].handle, cam_var.camera[0].id, */
+/*   if (!dc1394_set_feature_value(cam_var->camera[0].handle, cam_var->camera[0].id, */
 /*                                 FEATURE_TRIGGER, adj->value)) */
 /*     message_gpiv(_("Cannot set external trigger count")); */
 /*   else */
-/*     cam_var.feature_set[0].feature[FEATURE_TRIGGER-FEATURE_MIN].value = */
+/*     cam_var->feature_set[0].feature[FEATURE_TRIGGER-FEATURE_MIN].value = */
 /*        adj->value; */
 /* } */
 
@@ -482,9 +485,9 @@ on_checkbutton_camera_trigger (GtkWidget *widget,
  */
 {
     if (GTK_TOGGLE_BUTTON(widget)->active) {
-	gpiv_par.console__trigger_cam = TRUE;
+	gpiv_par->console__trigger_cam = TRUE;
     } else {
-	gpiv_par.console__trigger_cam = FALSE;
+	gpiv_par->console__trigger_cam = FALSE;
     }
 }
 
@@ -504,8 +507,8 @@ on_man_auto_menu (GtkWidget *widget,
     } var_type;
     
     var_type = atoi(gtk_object_get_data(GTK_OBJECT(widget), "var_type"));
-    if (!dc1394_auto_on_off(cam_var.camera[0].handle, 
-                            cam_var.camera[0].id,
+    if (!dc1394_auto_on_off(cam_var->camera[0].handle, 
+                            cam_var->camera[0].id,
                             feature, var_type)) {
         message_gpiv(_("on_man_auto_menu: Cannnot set auto / manual"));
     }
@@ -528,25 +531,25 @@ on_scale_changed (GtkAdjustment *adj,
 {
     switch((int)user_data) {
     case FEATURE_TEMPERATURE:
-        if (!dc1394_set_temperature(cam_var.camera[0].handle,
-                                    cam_var.camera[0].id,
+        if (!dc1394_set_temperature(cam_var->camera[0].handle,
+                                    cam_var->camera[0].id,
                                     adj->value))
             message_gpiv(_("on_scale_changed: Cannot set temperature"));
         else
-            cam_var.feature_set[0].feature[FEATURE_TEMPERATURE-FEATURE_MIN].
+            cam_var->feature_set[0].feature[FEATURE_TEMPERATURE-FEATURE_MIN].
                 value = adj->value;
         break;
 
     default:
 /*         g_message("on_scale_changed:: feature = %d value = %f",  */
 /*                   (gint) user_data, adj->value); */
-        if (!dc1394_set_feature_value(cam_var.camera[0].handle,
-                                      cam_var.camera[0].id,
+        if (!dc1394_set_feature_value(cam_var->camera[0].handle,
+                                      cam_var->camera[0].id,
                                       (gint) user_data,
                                       adj->value)) {
             message_gpiv(_("on_scale_changed: Cannot set feature"));
         } else {
-            cam_var.feature_set[0].feature[(gint) user_data - FEATURE_MIN].
+            cam_var->feature_set[0].feature[(gint) user_data - FEATURE_MIN].
                 value = adj->value;
         }
         break;
@@ -638,23 +641,23 @@ open_dac_img(GpivCamVar *cam_var,
 /*
  * parameter initializing of image
  */
-    gpiv_img_parameters_set(&img->image_par, FALSE);
+    gpiv_img_parameters_set(img->image->header, FALSE);
 
-    img->image_par.ncolumns = cam_var->capture[0].frame_width;
-    img->image_par.nrows = cam_var->capture[0].frame_height;
-    img->image_par.x_corr = gpiv_par.x_corr;
-    img->image_par.ncolumns__set = TRUE;
-    img->image_par.nrows__set = TRUE;
-    img->image_par.x_corr__set = TRUE;
+    img->image->header->ncolumns = cam_var->capture[0].frame_width;
+    img->image->header->nrows = cam_var->capture[0].frame_height;
+    img->image->header->x_corr = gpiv_par->x_corr;
+    img->image->header->ncolumns__set = TRUE;
+    img->image->header->nrows__set = TRUE;
+    img->image->header->x_corr__set = TRUE;
 
-    gpiv_img_cp_parameters (gl_image_par, &img->image_par, FALSE, FALSE);
+    gl_image_par = gpiv_img_cp_parameters (img->image->header);
     if (verbose) g_message("open_dac_img:: 1 creation_date = %s", 
-              img->image_par.creation_date);
+              img->image->header->creation_date);
 /* 
  * Apply time and date to creation_date (buffer) parameter
  */
     month = month_name(g_date_month(date));
-    g_snprintf(img->image_par.creation_date,
+    g_snprintf(img->image->header->creation_date,
                GPIV_MAX_CHARS,
                "%d %s %d %d:%d:%d",
                g_date_day(date), 
@@ -670,8 +673,8 @@ open_dac_img(GpivCamVar *cam_var,
     img->img1 = gpiv_alloc_img(img->image_par);
 /*     } */
 
-    for (i = 0; i < img->image_par.nrows ; i++) {
-        for (j = 0; j < img->image_par.ncolumns; j++) {
+    for (i = 0; i < img->image->header->nrows ; i++) {
+        for (j = 0; j < img->image->header->ncolumns; j++) {
 /*
  * format 640x480 = 1:1.3
  */
@@ -681,12 +684,12 @@ open_dac_img(GpivCamVar *cam_var,
 
 
 
-    if (gpiv_par.x_corr) {
+    if (gpiv_par->x_corr) {
  /*        if(alloc_mem) { */
         img->img2 = gpiv_alloc_img(img->image_par);
 /*         } */
-        for (i = 0; i < img->image_par.nrows ; i++) {
-            for (j = 0; j < img->image_par.ncolumns; j++) {
+        for (i = 0; i < img->image->header->nrows ; i++) {
+            for (j = 0; j < img->image->header->ncolumns; j++) {
 /*
  * format 640x480 = 1:1.3
  */
@@ -733,7 +736,7 @@ load_dac_buffer (GpivConsole *gpiv,
 
     g_snprintf (display_act->file_uri_name, GPIV_MAX_CHARS, "%s", fname);
     if((return_val = open_dac_img (cam_var, frameA, frameB, 
-                                   &display_act->img, FALSE))
+                                   display_act->img, FALSE))
        != 0) {
         gtk_object_destroy (GTK_OBJECT(display[ibuf]->mwin));
         if (ibuf > 0) {
@@ -764,14 +767,14 @@ load_dac_buffer (GpivConsole *gpiv,
  */
     create_background (display_act);
     create_img (display_act);
-    if (display_act->display_img1) {
+    if (display_act->img->exist_img ) {
         show_img1 (display_act);
     } else {
         hide_img1 (display_act);
     }
     
-    if (gl_image_par.x_corr) {
-        if (display_act->display_img2) {
+    if (gl_image_par->x_corr) {
+        if (display_act->img->exist_img) {
             show_img2 (display_act);
         } else {
             hide_img2 (display_act);
@@ -780,11 +783,11 @@ load_dac_buffer (GpivConsole *gpiv,
 
 
 /*     display_act->img.img_mean = image_mean(display_act->img.img1, */
-/*                                            gpiv_par.img_width,  */
-/*                                            gpiv_par.img_height); */
+/*                                            gpiv_par->img_width,  */
+/*                                            gpiv_par->img_height); */
 
 
-    if (gpiv_par.display__intregs == 1) {
+    if (gpiv_par->display__intregs == 1) {
         if (verbose) g_message("load_dac_buffer:: create_all_intregs");
         create_all_intregs(display_act);
     }
@@ -819,12 +822,12 @@ load_dac_buffer (GpivConsole *gpiv,
 /*    gpiv_img_cp_parameters(gl_image_par, display_act->img.image_par); */
 
    if (verbose) g_message ("load_dac_buffer:: ncolumns=%d nrows = %d",
-              display_act->img.image_par.ncolumns, display_act->img.image_par.nrows);
+              display_act->img->image->header->ncolumns, display_act->img->image->header->nrows);
     gtk_widget_set_size_request (display_act->canvas, 
                                  (gint) (display_act->zoom_factor * 
-                                         display_act->img.image_par.ncolumns), 
+                                         display_act->img->image->header->ncolumns), 
                                  (gint) (display_act->zoom_factor * 
-                                         display_act->img.image_par.nrows));
+                                         display_act->img->image->header->nrows));
     
 }
 
@@ -855,18 +858,18 @@ rec_and_display (GpivConsole *gpiv
  * been enabled only from camera
  */
 #ifdef ENABLE_TRIG
-    if (gpiv_par.process_trig) {
+    if (gpiv_par->process_trig) {
         mode = gl_trig_par.ttime.mode;
         cycles = gl_trig_par.ttime.cycles;
         DURATION = GPIV_TIMER_MODE__DURATION;
     } else {
-        mode = gl_cam_par.mode;
-        cycles = gl_cam_par.cycles;
+        mode = gl_cam_par->mode;
+        cycles = gl_cam_par->cycles;
         DURATION = GPIV_CAM_MODE__DURATION;
     }
 #else /* ENABLE_TRIG */
-    mode = gl_cam_par.mode;
-    cycles = gl_cam_par.cycles;
+    mode = gl_cam_par->mode;
+    cycles = gl_cam_par->cycles;
     DURATION = GPIV_CAM_MODE__DURATION;
 #endif /* ENABLE_TRIG */
 
@@ -877,7 +880,7 @@ rec_and_display (GpivConsole *gpiv
     if (mode == DURATION) {
         for (ibuf = 0; ibuf < nbufs; ibuf++) {
             if (display[ibuf] != NULL) {
-                close_buffer(gpiv, display[ibuf], &ibuf);
+                close_buffer(gpiv, display[ibuf]);
             }
         }
         gtk_clist_clear(GTK_CLIST(gpiv->clist_buf));
@@ -888,11 +891,11 @@ rec_and_display (GpivConsole *gpiv
  */
         for (ibuf = 0; ibuf < cycles; ibuf++) {
             img_frame[ibuf].A = 
-                gpiv_ucmatrix(cam_var.capture[0].frame_height, 
-                              cam_var.capture[0].frame_width);
-            if (gpiv_par.x_corr) {
-                img_frame[ibuf].B = gpiv_ucmatrix(cam_var.capture[0].frame_height, 
-                                                  cam_var.capture[0].frame_width);
+                gpiv_ucmatrix(cam_var->capture[0].frame_height, 
+                              cam_var->capture[0].frame_width);
+            if (gpiv_par->x_corr) {
+                img_frame[ibuf].B = gpiv_ucmatrix(cam_var->capture[0].frame_height, 
+                                                  cam_var->capture[0].frame_width);
             }
         }
 
@@ -943,10 +946,10 @@ rec_and_display (GpivConsole *gpiv
  * displaying and freeing image mem
  */
         for (ibuf = 0; ibuf < cycles; ibuf++) {
-            add_buffer(gpiv, gpiv_var.fn_last[0], ibuf, img_frame[ibuf].A, 
+            add_buffer(gpiv, gpiv_var->fn_last[0], ibuf, img_frame[ibuf].A, 
                        img_frame[ibuf].B);
             gpiv_free_ucmatrix(img_frame[ibuf].A);
-            if (gpiv_par.x_corr) {
+            if (gpiv_par->x_corr) {
                 gpiv_free_ucmatrix(img_frame[ibuf].B);
             }
         }
@@ -965,17 +968,17 @@ rec_and_display (GpivConsole *gpiv
 /*                                                  0.1); */
 
         img_frame[ibuf].A = 
-            gpiv_ucmatrix(cam_var.capture[0].frame_height, 
-                          cam_var.capture[0].frame_width);
-        if (gpiv_par.x_corr) {
-            img_frame[ibuf].B = gpiv_ucmatrix(cam_var.capture[0].frame_height, 
-                                              cam_var.capture[0].frame_width);
+            gpiv_ucmatrix(cam_var->capture[0].frame_height, 
+                          cam_var->capture[0].frame_width);
+        if (gpiv_par->x_corr) {
+            img_frame[ibuf].B = gpiv_ucmatrix(cam_var->capture[0].frame_height, 
+                                              cam_var->capture[0].frame_width);
         }
 
         while (!cancel_process) {
             rec_frame(&img_frame[ibuf]);
             while (g_main_iteration(FALSE));
-            renew_buffer(gpiv, gpiv_var.fn_last[0], ibuf, img_frame[ibuf].A, 
+            renew_buffer(gpiv, gpiv_var->fn_last[0], ibuf, img_frame[ibuf].A, 
                          img_frame[ibuf].B);
 /* BUGFIX: for Gtk2 */
 /*                     gtk_progress_bar_pulse ((GNOME_APPBAR(gpiv->appbar)) */
@@ -984,7 +987,7 @@ rec_and_display (GpivConsole *gpiv
         }
             
         gpiv_free_ucmatrix(img_frame[ibuf].A);
-        if (gpiv_par.x_corr) {
+        if (gpiv_par->x_corr) {
             gpiv_free_ucmatrix(img_frame[ibuf].B);
         }
         
@@ -1007,18 +1010,18 @@ thread_rec_frame(void *img_frame)
     my_frame = (ImgFrame *) img_frame;
 
 
-/*     unsigned char **frameA = gpiv_ucmatrix(cam_var.capture[0].frame_height,  */
-/*                           cam_var.capture[0].frame_width); */
+/*     unsigned char **frameA = gpiv_ucmatrix(cam_var->capture[0].frame_height,  */
+/*                           cam_var->capture[0].frame_width); */
 
 
     if (verbose) g_message("thread_rec_frame:: 0.1");
 /*
  * capture one frame
  */
-    if (dc1394_single_capture(cam_var.handle, &cam_var.capture[0]) 
+    if (dc1394_single_capture(cam_var->handle, &cam_var->capture[0]) 
         != DC1394_SUCCESS) {
-        dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);
-        raw1394_destroy_handle(cam_var.handle);
+        dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);
+        raw1394_destroy_handle(cam_var->handle);
         warning_gpiv(_("unable to capture a frame"));
 /*         return(); */
     } else {
@@ -1031,9 +1034,9 @@ thread_rec_frame(void *img_frame)
  */
 
         pthread_mutex_lock(&mutex_rec);
-        memcpy( frameA[0], (const char *) cam_var.capture[0].capture_buffer, 
-                sizeof(char) * cam_var.capture[0].frame_width * 
-                cam_var.capture[0].frame_height);
+        memcpy( frameA[0], (const char *) cam_var->capture[0].capture_buffer, 
+                sizeof(char) * cam_var->capture[0].frame_width * 
+                cam_var->capture[0].frame_height);
         pthread_mutex_unlock(&mutex_rec);
         if (verbose) g_message("thread_rec_frame:: 2");
     }    
@@ -1041,19 +1044,19 @@ thread_rec_frame(void *img_frame)
 /*
  * Repeat if cross correlation; x_corr = TRUE
  */
-    if (gpiv_par.x_corr) {
-        if (dc1394_single_capture(cam_var.handle, &cam_var.capture[0]) 
+    if (gpiv_par->x_corr) {
+        if (dc1394_single_capture(cam_var->handle, &cam_var->capture[0]) 
             != DC1394_SUCCESS) {
-            dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);
-            raw1394_destroy_handle(cam_var.handle);
+            dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);
+            raw1394_destroy_handle(cam_var->handle);
             warning_gpiv(_("unable to capture a frame"));
 /*             return(); */
         } else {
             
             pthread_mutex_lock(&mutex_rec);
-            memcpy( frameB[0], (const char *) cam_var.capture[0].capture_buffer, 
-                    sizeof(char) * cam_var.capture[0].frame_width * 
-                    cam_var.capture[0].frame_height);
+            memcpy( frameB[0], (const char *) cam_var->capture[0].capture_buffer, 
+                    sizeof(char) * cam_var->capture[0].frame_width * 
+                    cam_var->capture[0].frame_height);
             pthread_mutex_unlock(&mutex_rec);
         }
     }
@@ -1080,7 +1083,7 @@ thread_rec_frame_serie(ImgFrame img_frame[GPIV_NIMG_MAX]
 #ifdef ENABLE_TRIG
     cycles = gl_trig_par.ttime.cycles;
 #else /* ENABLE_TRIG */
-    cycles = gl_cam_par.cycles;
+    cycles = gl_cam_par->cycles;
 #endif /* ENABLE_TRIG */
 
 /* g_message("thread_rec_frame_series:: 0 with id = %d", (int) pthread_self ()); */
@@ -1106,10 +1109,10 @@ rec_frame(ImgFrame *img_frame
 
 /* g_message("rec_frame:: 0"); */
 
-    if (dc1394_single_capture(cam_var.handle, &cam_var.capture[0]) 
+    if (dc1394_single_capture(cam_var->handle, &cam_var->capture[0]) 
         != DC1394_SUCCESS) {
-        dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);
-        raw1394_destroy_handle(cam_var.handle);
+        dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);
+        raw1394_destroy_handle(cam_var->handle);
         g_warning("unable to capture a frame");
         return;
     }
@@ -1118,26 +1121,26 @@ rec_frame(ImgFrame *img_frame
  * Copy buffer content to tmp buffer array
  */
     memcpy( img_frame->A[0], 
-            (const char *) cam_var.capture[0].capture_buffer, 
-            sizeof(char) * cam_var.capture[0].frame_width * 
-            cam_var.capture[0].frame_height);
+            (const char *) cam_var->capture[0].capture_buffer, 
+            sizeof(char) * cam_var->capture[0].frame_width * 
+            cam_var->capture[0].frame_height);
     
-    if (gpiv_par.x_corr) {
+    if (gpiv_par->x_corr) {
 /*
  * capture second frame
  */
-        if (dc1394_single_capture(cam_var.handle, &cam_var.capture[0]) 
+        if (dc1394_single_capture(cam_var->handle, &cam_var->capture[0]) 
             != DC1394_SUCCESS) {
-            dc1394_release_camera(cam_var.handle, &cam_var.capture[0]);
-            raw1394_destroy_handle(cam_var.handle);
+            dc1394_release_camera(cam_var->handle, &cam_var->capture[0]);
+            raw1394_destroy_handle(cam_var->handle);
             g_warning("unable to capture a frame");
             return;
         }
 
         memcpy( img_frame->B[0], 
-                (const char *) cam_var.capture[0].capture_buffer, 
-                sizeof(char) * cam_var.capture[0].frame_width * 
-                cam_var.capture[0].frame_height);   
+                (const char *) cam_var->capture[0].capture_buffer, 
+                sizeof(char) * cam_var->capture[0].frame_width * 
+                cam_var->capture[0].frame_height);   
     }
     
 /* g_message("rec_frame:: 3/3"); */
@@ -1186,30 +1189,30 @@ add_buffer(GpivConsole *gpiv,
 
     g_snprintf(cbuf, 4, "%d", ibuf);
 
-    if (gpiv_var.fname_date
-        && gpiv_var.fname_time) {
-        fname_base = g_strdup(g_strconcat(gpiv_var.fn_last[0],
+    if (gpiv_var->fname_date
+        && gpiv_var->fname_time) {
+        fname_base = g_strdup(g_strconcat(gpiv_var->fn_last[0],
                                           (gchar *) cdate, 
                                           (gchar *) ctime, 
                                           (gchar *) cbuf, 
                                           NULL));
-    } else if (gpiv_var.fname_date) {
-        fname_base = g_strdup(g_strconcat(gpiv_var.fn_last[0],
+    } else if (gpiv_var->fname_date) {
+        fname_base = g_strdup(g_strconcat(gpiv_var->fn_last[0],
                                           (gchar *) cdate, 
                                           (gchar *) cbuf, 
                                           NULL));
-    } else if (gpiv_var.fname_time) {
-        fname_base = g_strdup(g_strconcat(gpiv_var.fn_last[0],
+    } else if (gpiv_var->fname_time) {
+        fname_base = g_strdup(g_strconcat(gpiv_var->fn_last[0],
                                           (gchar *) ctime, 
                                           (gchar *) cbuf, 
                                           NULL));
     } else {
-        fname_base = g_strdup(g_strconcat(gpiv_var.fn_last[0],
+        fname_base = g_strdup(g_strconcat(gpiv_var->fn_last[0],
                                           (gchar *) cbuf, 
                                           NULL));   
     }
 
-    load_dac_buffer(gpiv, &cam_var, FALSE, fname_base, ibuf, frameA, frameB, 
+    load_dac_buffer(gpiv, cam_var, FALSE, fname_base, ibuf, frameA, frameB, 
                     INSERT);
     nbufs++;
 
@@ -1242,14 +1245,14 @@ renew_buffer(GpivConsole *gpiv,
         display_act = display[ibuf];
 
         recreate_img(display_act, frameA, frameB);
-        if (display_act->display_img1) {
+        if (display_act->img->exist_img) {
             show_img1(display_act);
         } else {
             hide_img1(display_act);
         }
         
-        if (gl_image_par.x_corr) {
-            if (display_act->display_img2) {
+        if (gl_image_par->x_corr) {
+            if (display_act->img->exist_img) {
                 show_img2(display_act);
             } else {
                 hide_img2(display_act);
@@ -1283,36 +1286,36 @@ recreate_img(Display * disp,
     gint depth = 8;
 
     assert (disp != NULL);
-    assert (disp->img.img1 != NULL);
-    assert (disp->img.rgbbuf_img1 != NULL);
-    if (disp->img.image_par.x_corr) {
-        assert (disp->img.img2 != NULL);
-        assert (disp->img.rgbbuf_img2 != NULL);
+    //assert (disp->img->img1 != NULL);
+    assert (disp->img->rgbbuf_img1 != NULL);
+    if (disp->img->image->header->x_corr) {
+      //  assert (disp->img->img2 != NULL);
+        assert (disp->img->rgbbuf_img2 != NULL);
     }
-    assert (disp->img.exist_img);
+    assert (disp->img->exist_img);
     
 
-    fact = fact << (disp->img.image_par.depth - depth);
-    disp->img.rgb_img_width = disp->img.image_par.ncolumns * 3;
-    while ((disp->img.rgb_img_width) % 4 != 0) {
-        disp->img.rgb_img_width++;
+    fact = fact << (disp->img->image->header->depth - depth);
+    disp->img->rgb_img_width = disp->img->image->header->ncolumns * 3;
+    while ((disp->img->rgb_img_width) % 4 != 0) {
+        disp->img->rgb_img_width++;
     } 
     
-    pixbuf1 = gdk_pixbuf_new_from_data(disp->img.rgbbuf_img1,
+    pixbuf1 = gdk_pixbuf_new_from_data(disp->img->rgbbuf_img1,
                                        GDK_COLORSPACE_RGB,
                                        FALSE,          /* gboolean has_alpha */
-                                       disp->img.image_par.depth,
-                                       disp->img.image_par.ncolumns,
-                                       disp->img.image_par.nrows,
-                                       disp->img.rgb_img_width, /* rowstride */ 
+                                       disp->img->image->header->depth,
+                                       disp->img->image->header->ncolumns,
+                                       disp->img->image->header->nrows,
+                                       disp->img->rgb_img_width, /* rowstride */ 
                                        NULL, 
                                        NULL);
     
 
 
-    pos1 = disp->img.rgbbuf_img1;
-   for (i = 0; i < disp->img.image_par.nrows; i++) {
-	for (j = 0; j < disp->img.image_par.ncolumns; j++) {
+    pos1 = disp->img->rgbbuf_img1;
+   for (i = 0; i < disp->img->image->header->nrows; i++) {
+	for (j = 0; j < disp->img->image->header->ncolumns; j++) {
 	    *pos1++ =  (guchar) (frameA[i][j] / fact);
 	    *pos1++ =  (guchar) (frameA[i][j] / fact);
 	    *pos1++ =  (guchar) (frameA[i][j] / fact);
@@ -1320,11 +1323,11 @@ recreate_img(Display * disp,
     }
 
 
-    gnome_canvas_item_set(GNOME_CANVAS_ITEM (disp->img.gci_img1),
+    gnome_canvas_item_set(GNOME_CANVAS_ITEM (disp->img->gci_img1),
                           "pixbuf", pixbuf1,
                           NULL);
-/*     gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (disp->img.gci_img1)); */
-/*     gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (disp->img.gci_img1)); */
+/*     gnome_canvas_item_raise_to_top (GNOME_CANVAS_ITEM (disp->img->gci_img1)); */
+/*     gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (disp->img->gci_img1)); */
 
 /* gtk_widget_pop_visual(); */
 /*   gtk_widget_pop_colormap(); */
@@ -1334,27 +1337,27 @@ recreate_img(Display * disp,
     
     
     
-/*     if(image_par.x_corr) { */
+/*     if(image->header->x_corr) { */
 /*         pos2 = NULL; */
         
-/*         disp->img.rgbbuf_img2 = g_malloc(disp->img.rgb_img_width * 3 * */
-/*                                          gpiv_par.img_height); */
+/*         disp->img->rgbbuf_img2 = g_malloc(disp->img->rgb_img_width * 3 * */
+/*                                          gpiv_par->img_height); */
         
-/*         pixbuf2 = gdk_pixbuf_new_from_data(disp->img.rgbbuf_img2, */
+/*         pixbuf2 = gdk_pixbuf_new_from_data(disp->img->rgbbuf_img2, */
 /*                                            GDK_COLORSPACE_RGB, */
 /*                                            FALSE,  */
 /*                                            depth,  */
-/*                                            gpiv_par.img_width,  */
-/*                                            gpiv_par.img_height, */
-/*                                            disp->img.rgb_img_width,  */
+/*                                            gpiv_par->img_width,  */
+/*                                            gpiv_par->img_height, */
+/*                                            disp->img->rgb_img_width,  */
 /*                                            NULL,  */
 /*                                            NULL); */
         
-/*         if (disp->img.gci_img2 != NULL) { */
+/*         if (disp->img->gci_img2 != NULL) { */
 /*             destroy_img(disp); */
 /*         } */
 
-/*         disp->img.gci_img2 =  */
+/*         disp->img->gci_img2 =  */
 /*             gnome_canvas_item_new( gnome_canvas_root( GNOME_CANVAS */
 /*                                                       (disp->canvas)), */
 /*                                    gnome_canvas_pixbuf_get_type (), */
@@ -1362,9 +1365,9 @@ recreate_img(Display * disp,
 /*                                    NULL); */
         
         
-/*         pos2 = disp->img.rgbbuf_img2; */
-/*         for (i = 0; i < gpiv_par.img_height; i++) { */
-/*             for (j = 0; j < gpiv_par.img_width; j++) { */
+/*         pos2 = disp->img->rgbbuf_img2; */
+/*         for (i = 0; i < gpiv_par->img_height; i++) { */
+/*             for (j = 0; j < gpiv_par->img_width; j++) { */
 /*                 *pos2++ = (guchar) (frameB[i][j] / fact); */
 /*                 *pos2++ = (guchar) (frameB[i][j] / fact); */
 /*                 *pos2++ = (guchar) (frameB[i][j] / fact); */
@@ -1374,7 +1377,7 @@ recreate_img(Display * disp,
 /*         gdk_pixbuf_unref (pixbuf2); */
         
 /*     } else { */
-        disp->img.gci_img2 = disp->img.gci_img2;
+        disp->img->gci_img2 = disp->img->gci_img2;
 /*     } */
     
 }
