@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of gpiv.
 
@@ -28,6 +29,9 @@
 /*
  * Data acquisition header interface
  * $Log: dac_interface.c,v $
+ * Revision 1.6  2008-09-16 11:17:42  gerber
+ * Updated because of cvs conflict
+ *
  * Revision 1.4  2005/03/01 14:43:46  gerber
  * updated documentation
  *
@@ -94,7 +98,7 @@ create_camera_menu(GnomeApp *main_window,
     gtk_container_add(GTK_CONTAINER (cam->vbox_cam),
 		      cam->camera_select);
 
-    if (cam_var.numCameras >= 1) {
+    if (cam_var->numCameras >= 1) {
         gtk_widget_set_sensitive (cam->camera_select, TRUE);
     } else {
         gtk_widget_set_sensitive (cam->camera_select, FALSE );
@@ -103,14 +107,14 @@ create_camera_menu(GnomeApp *main_window,
 
 
     cam->camera_select_menu = gtk_menu_new ();
-    if (cam_var.numCameras > 0) {
-        for (i = 0; i < cam_var.numCameras; i++) {
+    if (cam_var->numCameras > 0) {
+        for (i = 0; i < cam_var->numCameras; i++) {
             g_snprintf(tmp,
                        GPIV_MAX_CHARS, 
                        "Node %d: %s %s",
-                       cam_var.camera[i].id, 
-                       cam_var.camera[i].vendor, 
-                       cam_var.camera[i].model);
+                       cam_var->camera[i].id, 
+                       cam_var->camera[i].vendor, 
+                       cam_var->camera[i].model);
             cam->menu_item = gtk_menu_item_new_with_label (_(tmp));
             gtk_widget_show (cam->menu_item);
             gtk_menu_append (GTK_MENU (cam->camera_select_menu), 
@@ -124,10 +128,10 @@ create_camera_menu(GnomeApp *main_window,
 /*
  * BUGFIX apply last camera to img_par.source
  */
-            g_snprintf(gl_image_par.source, GPIV_MAX_CHARS, "%s %s", 
-                       cam_var.camera[i].vendor,
-                       cam_var.camera[i].model);
-            gl_image_par.source__set = TRUE;
+            g_snprintf(gl_image_par->source, GPIV_MAX_CHARS, "%s %s", 
+                       cam_var->camera[i].vendor,
+                       cam_var->camera[i].model);
+            gl_image_par->source__set = TRUE;
         }
     } else {
         g_snprintf(tmp,
@@ -140,8 +144,8 @@ create_camera_menu(GnomeApp *main_window,
         gtk_option_menu_set_menu (GTK_OPTION_MENU (cam->camera_select), 
                                   cam->camera_select_menu);
 
-        g_snprintf(gl_image_par.source, GPIV_MAX_CHARS, "No camera");
-        gl_image_par.source__set = TRUE;
+        g_snprintf(gl_image_par->source, GPIV_MAX_CHARS, "No camera");
+        gl_image_par->source__set = TRUE;
     }
 
 
@@ -172,12 +176,12 @@ create_format_menu(GnomeApp *main_window,
     char tmp[GPIV_MAX_CHARS];
     quadlet_t modes, formats;
 
-    if (cam_var.numCameras > 0) {
-        dc1394_query_supported_formats(cam_var.camera[0].handle, 
-                                       cam_var.camera[0].id, 
+    if (cam_var->numCameras > 0) {
+        dc1394_query_supported_formats(cam_var->camera[0].handle, 
+                                       cam_var->camera[0].id, 
                                        &formats);
-        dc1394_query_supported_modes(cam_var.camera[0].handle, 
-                                     cam_var.camera[0].id, 
+        dc1394_query_supported_modes(cam_var->camera[0].handle, 
+                                     cam_var->camera[0].id, 
                                      FORMAT_VGA_NONCOMPRESSED, 
                                      &modes);
     }
@@ -200,7 +204,7 @@ create_format_menu(GnomeApp *main_window,
     
     
     cam->format_menu_menu = gtk_menu_new ();
-    if (cam_var.numCameras > 0) {
+    if (cam_var->numCameras > 0) {
 /*
  * Format 0
  */
@@ -366,14 +370,14 @@ create_fps_menu(GnomeApp *main_window,
     gchar tmp[GPIV_MAX_CHARS];
     quadlet_t value;
 
-    if (cam_var.numCameras > 0) {
-        if (cam_var.misc_info[0].format == FORMAT_SCALABLE_IMAGE_SIZE) {
+    if (cam_var->numCameras > 0) {
+        if (cam_var->misc_info[0].format == FORMAT_SCALABLE_IMAGE_SIZE) {
             value = 0; /* format 7 has no fixed framerates */
         } else {
-            err=dc1394_query_supported_framerates(cam_var.camera[0].handle, 
-                                                  cam_var.camera[0].id, 
-                                                  cam_var.misc_info[0].format, 
-                                                  cam_var.misc_info[0].mode, 
+            err=dc1394_query_supported_framerates(cam_var->camera[0].handle, 
+                                                  cam_var->camera[0].id, 
+                                                  cam_var->misc_info[0].format, 
+                                                  cam_var->misc_info[0].mode, 
                                                   &value);
             if (!err) g_warning("Could not query supported framerates");
         }
@@ -399,7 +403,7 @@ create_fps_menu(GnomeApp *main_window,
     
     
     cam->fps_menu_menu = gtk_menu_new ();
-    if (cam_var.numCameras > 0) {
+    if (cam_var->numCameras > 0) {
         k = 0;
         for (f=FRAMERATE_MIN, i=0; f <= FRAMERATE_MAX; i++, f++) {
 /*
@@ -428,26 +432,26 @@ create_fps_menu(GnomeApp *main_window,
         gtk_option_menu_set_menu (GTK_OPTION_MENU (cam->fps_menu), 
                                   cam->fps_menu_menu);
         
-        if (index[cam_var.misc_info[0].framerate-FRAMERATE_MIN] < 0 ) {
+        if (index[cam_var->misc_info[0].framerate-FRAMERATE_MIN] < 0 ) {
 // previously selected framerate unsupported!!
 // automatically switch to nearest fps available
             for (i = 1; i <= ((NUM_FRAMERATES>>1) +1); i++) {
 // search radius is num_framerates/2 +1 for safe rounding     
-                if (((cam_var.misc_info[0].framerate-FRAMERATE_MIN-i)>=0) && cont) {
-                    if (index[cam_var.misc_info[0].framerate - FRAMERATE_MIN-i]
+                if (((cam_var->misc_info[0].framerate-FRAMERATE_MIN-i)>=0) && cont) {
+                    if (index[cam_var->misc_info[0].framerate - FRAMERATE_MIN-i]
                         >= 0) {
 // try down
-                        new_framerate=cam_var.misc_info[0].framerate - i;
+                        new_framerate=cam_var->misc_info[0].framerate - i;
                         cont=DC1394_FALSE;
                     }
                 }
-                if (((cam_var.misc_info[0].framerate - FRAMERATE_MIN + i)
+                if (((cam_var->misc_info[0].framerate - FRAMERATE_MIN + i)
                      < NUM_FRAMERATES) 
                     && cont) {
-                    if (index[cam_var.misc_info[0].framerate - FRAMERATE_MIN + i]
+                    if (index[cam_var->misc_info[0].framerate - FRAMERATE_MIN + i]
                         >=0) {
 // try up
-                        new_framerate=cam_var.misc_info[0].framerate + i;
+                        new_framerate=cam_var->misc_info[0].framerate + i;
                         cont=DC1394_FALSE;
                     }
                 }
@@ -456,15 +460,15 @@ create_fps_menu(GnomeApp *main_window,
                      "create_fps_menu: Invalid framerate. Updating to nearest: %s\n",
                      fps_label_list[new_framerate-FRAMERATE_MIN]);
             warning_gpiv(tmp);
-            err = dc1394_set_video_framerate(cam_var.camera[0].handle,
-                                             cam_var.camera[0].id,
+            err = dc1394_set_video_framerate(cam_var->camera[0].handle,
+                                             cam_var->camera[0].id,
                                              new_framerate);
             if (!err)
                 warning_gpiv("create_fps_menu: Cannot set video framerate");
-            cam_var.misc_info[0].framerate = new_framerate;
+            cam_var->misc_info[0].framerate = new_framerate;
         }
         gtk_option_menu_set_history (GTK_OPTION_MENU (cam->fps_menu), 
-                                     index[cam_var.misc_info[0].framerate -
+                                     index[cam_var->misc_info[0].framerate -
                                            FRAMERATE_MIN]);
         
     }    
@@ -488,9 +492,9 @@ create_trigger_mode(GnomeApp *main_window,
     gint index[NUM_TRIGGER_MODE];
 
 
-    if (cam_var.numCameras > 0) {
-        err = dc1394_query_feature_characteristics(cam_var.camera[0].handle,
-                                                   cam_var.camera[0].id,
+    if (cam_var->numCameras > 0) {
+        err = dc1394_query_feature_characteristics(cam_var->camera[0].handle,
+                                                   cam_var->camera[0].id,
                                                    FEATURE_TRIGGER,
                                                    &value);
         if (!err) g_warning("Could not query trigger feature characteristics");
@@ -518,7 +522,7 @@ create_trigger_mode(GnomeApp *main_window,
     
     
     cam->trigger_mode_menu = gtk_menu_new ();
-    if (cam_var.numCameras > 0) {
+    if (cam_var->numCameras > 0) {
         if (modes) {
 /*
  * at least one mode present
@@ -548,7 +552,7 @@ create_trigger_mode(GnomeApp *main_window,
  * sets the active menu item:
  */
         gtk_option_menu_set_history (GTK_OPTION_MENU (cam->trigger_mode), 
-                                     index[cam_var.feature_set[0].feature
+                                     index[cam_var->feature_set[0].feature
                                            [FEATURE_TRIGGER - FEATURE_MIN]
                                            .trigger_mode]);
     }
@@ -588,14 +592,14 @@ create_camera_feature_menu_scale(GnomeApp *main_window,
     
 
 
-     if (cam_var.numCameras > 0
-         && cam_var.feature_set[0].feature[FEATURE - FEATURE_MIN].
+     if (cam_var->numCameras > 0
+         && cam_var->feature_set[0].feature[FEATURE - FEATURE_MIN].
          readout_capable) {
          adj_scale =
              gtk_adjustment_new(0,
-                                cam_var.feature_set[0].
+                                cam_var->feature_set[0].
                                 feature[FEATURE - FEATURE_MIN].min,
-                                cam_var.feature_set[0].
+                                cam_var->feature_set[0].
                                 feature[FEATURE - FEATURE_MIN].max,
                                 1,
                                 10,
@@ -622,15 +626,15 @@ create_camera_feature_menu_scale(GnomeApp *main_window,
      gtk_scale_set_digits (GTK_SCALE (scale), 
                            0);
      
-     if (cam_var.numCameras > 0) {
-         if (cam_var.feature_set[0].feature[FEATURE - FEATURE_MIN].
+     if (cam_var->numCameras > 0) {
+         if (cam_var->feature_set[0].feature[FEATURE - FEATURE_MIN].
          readout_capable) {
              gtk_adjustment_set_value(GTK_ADJUSTMENT (adj_scale),
-                                      cam_var.feature_set[0].
+                                      cam_var->feature_set[0].
                                       feature[FEATURE - FEATURE_MIN].value);
          }
          
-         if (cam_var.feature_set[0].feature[FEATURE - FEATURE_MIN].
+         if (cam_var->feature_set[0].feature[FEATURE - FEATURE_MIN].
              manual_capable) {
 /*
  * set glider active and connect
@@ -660,8 +664,8 @@ create_camera_feature_menu_scale(GnomeApp *main_window,
 
 
     option_menu = gtk_menu_new ();
-    if (cam_var.numCameras > 0) {
-        if (cam_var.feature_set[0].feature[FEATURE - FEATURE_MIN].
+    if (cam_var->numCameras > 0) {
+        if (cam_var->feature_set[0].feature[FEATURE - FEATURE_MIN].
             manual_capable) {
 /* 
  * add menu man
@@ -685,7 +689,7 @@ create_camera_feature_menu_scale(GnomeApp *main_window,
                                 (int*) FEATURE);
         }    
         
-        if (cam_var.feature_set[0].feature[FEATURE - FEATURE_MIN].
+        if (cam_var->feature_set[0].feature[FEATURE - FEATURE_MIN].
             auto_capable) {
 /*
  * add menu auto
@@ -709,8 +713,8 @@ create_camera_feature_menu_scale(GnomeApp *main_window,
 /*
  * add menu non avail.
  */
-        if (!cam_var.feature_set[0].feature[FEATURE - FEATURE_MIN].auto_capable
-            && !cam_var.feature_set[0].feature[FEATURE - FEATURE_MIN].
+        if (!cam_var->feature_set[0].feature[FEATURE - FEATURE_MIN].auto_capable
+            && !cam_var->feature_set[0].feature[FEATURE - FEATURE_MIN].
             manual_capable
             ) {
             gtk_widget_set_sensitive (option, 
@@ -979,8 +983,8 @@ create_dac (GnomeApp *main_window,
 /*     dac->combo_fname_items = g_list_append (dac->combo_fname_items,  */
 /*                                           (gpointer) dac_par.fname); */
 
-    for (i = 0; i < gpiv_var.number_fnames_last; i++) {
-        fname_last_base = g_strdup(g_basename(gpiv_var.fn_last[i]));
+    for (i = 0; i < gpiv_var->number_fnames_last; i++) {
+        fname_last_base = g_strdup(g_basename(gpiv_var->fn_last[i]));
         strtok(fname_last_base, ".");
         dac->combo_fname_items = g_list_append (dac->combo_fname_items, 
                                                 (gpointer) g_basename
@@ -1057,7 +1061,7 @@ create_dac (GnomeApp *main_window,
                        NULL);
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
                                 (dac->checkbutton_fname_date),
-                                gpiv_var.fname_date);
+                                gpiv_var->fname_date);
 
 
 
@@ -1102,7 +1106,7 @@ create_dac (GnomeApp *main_window,
                        NULL);
     gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
                                 (dac->checkbutton_fname_time),
-                                gpiv_var.fname_time);
+                                gpiv_var->fname_time);
 
 
 
@@ -1610,7 +1614,7 @@ create_dac (GnomeApp *main_window,
 
 #ifdef ENABLE_CAM
     dac->trig->spinbutton_adj_trigger_nf =
-	gtk_adjustment_new(gl_cam_par.cycles,
+	gtk_adjustment_new(gl_cam_par->cycles,
 			   GPIV_CAMPAR_CYCLES_MIN, 
 			   MAX_BUFS, /* GPIV_CAMPAR_CYCLES_MAX */
 			   ADJ_ISTEP,
@@ -2233,7 +2237,7 @@ create_dac (GnomeApp *main_window,
  * Setting initial values
  */
 #ifdef ENABLE_CAM
-    if (gl_cam_par.mode == GPIV_CAM_MODE__PERIODIC) {
+    if (gl_cam_par->mode == GPIV_CAM_MODE__PERIODIC) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_1),
                                     TRUE);
@@ -2243,7 +2247,7 @@ create_dac (GnomeApp *main_window,
                                     FALSE);
     }
 
-    if (gl_cam_par.mode == GPIV_CAM_MODE__DURATION) {
+    if (gl_cam_par->mode == GPIV_CAM_MODE__DURATION) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON
 				    (dac->trig->radiobutton_mouse_2),
                                     TRUE);
