@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 
+   Gerber van der Graaf <gerber_graaf@users.sourceforge.net>
 
    This file is part of gpiv.
 
@@ -27,7 +28,25 @@
 
 /*
  * Graphical User Interface for gpiv
- * $Log: gpiv_gtk.h,v $
+ * $Log: gpiv_gui.h,v $
+ * Revision 1.6  2008-10-09 14:43:37  gerber
+ * paralellized with OMP and MPI
+ *
+ * Revision 1.5  2008-09-25 13:32:22  gerber
+ * Adapted for use on cluster (using MPI/OMP) parallelised gpiv_rr from gpivtools)
+ *
+ * Revision 1.4  2008-09-16 10:13:56  gerber
+ * 2nd update because of cvs conflict
+ *
+ * Revision 1.3  2008-09-16 10:11:02  gerber
+ * Updated because of cvs conflict
+ *
+ * Revision 1.2  2005-06-15 15:06:22  gerber
+ * Optional Anti Aliased canvas for viewer
+ *
+ * Revision 1.1  2005/06/15 09:40:40  gerber
+ * debugged, optimized
+ *
  * Revision 1.9  2005/01/19 15:53:41  gerber
  * Initiation of Data Acquisition (DAC); trigerring of lasers and camera
  * by using RTAI and Realtime Linux, recording images from IEEE1394
@@ -90,7 +109,7 @@
 
 
 /*  Revision Control System (RCS) version */
-#define RCSID "$Id: gpiv_gtk.h,v 1.9 2005/01/19 15:53:41 gerber Exp $" 
+#define RCSID "$Id: gpiv_gui.h,v 1.6 2008-10-09 14:43:37 gerber Exp $" 
 #define ERR_IVAL = 99           /* Some arbitrary integer error value */
 #define ADJ_MIN -50.0	        /* minimum value for adjustment */
 #define ADJ_MAX 50.0	        /* maximum value for adjustment */
@@ -101,6 +120,10 @@
 
 #define MAX_LIST 5
 
+#ifdef ENABLE_MPI
+#define MPIRUN_CMD "mpirun -np"
+#endif
+
 /*
  * SVGA: 1280 x 1024
  * Sony PCR-100 video camera: 1152 x 864
@@ -344,8 +367,8 @@ struct __GpivPar {
     enum ImgFmt img_fmt;                        /* Image data / header will be stored to this format */
     gboolean img_fmt__set;
 
-    gboolean hdf;                               /* store data in hdf 5 format, with .gpi extension */
-    gboolean hdf__set;                          /* store data in hdf 5 format, with .gpi extension */
+    gboolean hdf;                               /* store data in hdf 5 format, with .h5 extension */
+    gboolean hdf__set;                          /* store data in hdf 5 format, with .h5 extension */
 
     gboolean print_par;                         /* Prints parameters to stdout */
     gboolean print_par__set;
@@ -452,6 +475,10 @@ struct __GpivPar {
     gboolean process__vorstra;                  /* used by gpiv toolbar to run vorstra */
     gboolean process__vorstra__set;             /* used by gpiv toolbar to run vorstra */
     
+#ifdef ENABLE_MPI
+    gint mpi_nodes;                             /* number of cluster nodes used for parallel MPI execution */
+    gboolean mpi_nodes__set;                    /* number of cluster nodes used for parallel MPI execution */
+#endif /* ENBALE MPI */
 
 }  gp, *default_par, *gpiv_par;
 
