@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of gpiv.
 
@@ -28,6 +29,12 @@
 /*
  * main routines of gpiv
  * $Log: main.c,v $
+ * Revision 1.30  2008-10-09 14:43:37  gerber
+ * paralellized with OMP and MPI
+ *
+ * Revision 1.29  2008-04-28 12:00:57  gerber
+ * hdf-formatted files are now with .hdf extension (previously: .gpi)
+ *
  * Revision 1.28  2007-12-19 08:42:35  gerber
  * debugged
  *
@@ -249,6 +256,15 @@ scan_parameters()
         gnome_config_set_bool ("hdf", ldp->hdf);
     }
     
+#ifdef ENABLE_MPI
+    ldp->mpi_nodes = 
+        gnome_config_get_int_with_default ("mpi_nodes=4", &used_default);
+    ldp->mpi_nodes__set = TRUE;
+    if (used_default) {
+        g_message ("mpi_nodes = %d from default", ldp->mpi_nodes);
+        gnome_config_set_int ("mpi_nodes", ldp->mpi_nodes);
+    }
+#endif /* ENABLE_MPI */
 
 
 
@@ -520,7 +536,7 @@ scan_parameters()
         g_message ("display__piv = %d from default", ldp->display__piv);
         gnome_config_set_bool ("display__piv", ldp->display__piv);
     }
-    
+
 
     gnome_config_pop_prefix ();
     gnome_config_sync();
