@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 
+   Gerber van der Graaf <gerber_graaf@users.sourceforge.net>
 
    This file is part of gpiv.
 
@@ -36,8 +37,13 @@ static const struct poptOption options [] = {
      N_("store image and header in PNG (0), raw (1) or HDF5 (2) format"), NULL},
 
     {"hdf", '\0', POPT_ARG_NONE, &gp.hdf, 0, 
-     N_("store resulting data in HDF5 format with .gpi extension"), NULL},
+     N_("store resulting data in HDF5 format with .h5 extension"), NULL},
         
+#ifdef ENABLE_MPI
+    {"mpi_nodes", '\0', POPT_ARG_INT, &gp.mpi_nodes, 0, 
+     N_("number of nodes for parallel execution on cluster using MPI"), N_("INT")},
+#endif /* ENABLE_MPI */
+
     {"print", 'p', POPT_ARG_NONE, &gp.print_par, 0, 
      N_("print parameters and other info to stdout"), NULL},
         
@@ -129,6 +135,6 @@ static const struct poptOption options [] = {
         
     {"process__vorstra", '\0', POPT_ARG_NONE, &gp.process__vorstra, 0, 
      N_("executes vorticity / strain calculation"), NULL},
-        
+
     {NULL, '\0', 0, NULL, 0}
 };
