@@ -5,7 +5,9 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2006 Gerber van der Graaf
+   Copyright (C) 2006, 2007, 2008
+   Gerber van der Graaf
+
    This file is part of gpiv.
 
    Gpiv is free software; you can redistribute it and/or modify
@@ -24,7 +26,19 @@
 
 ----------------------------------------------------------------------*/
 
-/* $Log: $
+/* $Log: piveval_interrogate.c,v $
+/* Revision 1.4  2008-10-09 15:19:03  gerber
+/* Release 0.6.0 using paralellized code
+/*
+/* Revision 1.3  2008-10-09 14:43:37  gerber
+/* paralellized with OMP and MPI
+/*
+/* Revision 1.2  2008-09-25 13:32:22  gerber
+/* Adapted for use on cluster (using MPI/OMP) paralellised gpiv_rr from gpivtools)
+/*
+/* Revision 1.1  2008-09-16 10:17:36  gerber
+/* added piveval_interrogate routines
+/*
  */
 
 #include "gpiv_gui.h"
@@ -72,6 +86,15 @@ update_pivdata_imgdeform_zoff (const GpivImage *image,
                                gboolean verbose
                                );
 
+#ifdef ENABLE_MPI
+static GpivPivData *
+exec_piv_mpi (GpivImage *image, 
+              GpivPivPar *piv_par, 
+              GpivValidPar *valid_par,
+              GpivConsole *gpiv
+              );
+#endif /* ENABLE_MPI */
+
 /*
  * Program-wide public piv interrogation functions
  */
@@ -81,6 +104,7 @@ void
 exec_piv (GpivConsole *gpiv
          )
 /*-----------------------------------------------------------------------------
+ * Performs the execution of image interrogation for PIV
  */
 {
     char *err_msg = NULL;
@@ -176,28 +200,40 @@ This will be reset automatically."),
     }
     gpiv_valid_print_parameters (stdout, display_act->pida->valid_par);
 
+#ifdef USE_LIBGPIV_INTERR
+#undef USE_LIBGPIV_INTERR
+#endif
+
     if ((display_act->pida->piv_data =
-#define USE_MY_INTERR
-#ifdef USE_MY_INTERR
-/* Gpiv's own function for image interrogation */
-         interrogate_img (display_act->img->image, 
-                          display_act->pida->piv_par, 
-                          display_act->pida->valid_par, 
-                          gpiv)
-#else
-/* Library function */
+#ifdef ENABLE_MPI
+/* Calling extern tool gpiv_rr from gpivtools with MPI enabled */
+         exec_piv_mpi(display_act->img->image, 
+                      display_act->pida->piv_par, 
+                      display_act->pida->valid_par,
+                      gpiv)
+
+#elif USE_LIBGPIV_INTERR
+/* Libgpiv's function for image interrogation */
          gpiv_piv_interrogate_img (display_act->img->image, 
                                    display_act->pida->piv_par, 
                                    display_act->pida->valid_par, 
                                    TRUE)
-#endif
-#ifdef USE_MY_INTERR
-#undef USE_MY_INTERR
+#else
+/* Gpiv's function for image interrogation */
+         interrogate_img (display_act->img->image, 
+                          display_act->pida->piv_par, 
+                          display_act->pida->valid_par, 
+                          gpiv)
 #endif
          ) == NULL) {
         warning_gpiv ("exec_piv: failing interrogate_img");
         return;
     }
+
+#ifdef USE_LIBGPIV_INTERR
+#undef USE_LIBGPIV_INTERR
+#endif
+
     display_act->pida->exist_piv = TRUE;
 
 /*
@@ -872,3 +908,111 @@ update_pivdata_imgdeform_zoff (const GpivImage *image,
 }
 
 
+#ifdef ENABLE_MPI
+static GpivPivData *
+exec_piv_mpi (GpivImage *image, 
+              GpivPivPar *piv_par, 
+              GpivValidPar *valid_par,
+              GpivConsole *gpiv
+              )
+/*-----------------------------------------------------------------------------
+ * Interrogates an image on a distributed memory (Beowulf) cluster 
+ * using gpiv_rr from the gpivtools package
+ */
+{
+    GpivPivData *pd = NULL;
+    FILE *fp = NULL;
+    gchar *command = NULL;
+    const gchar      *tmp_dir = g_get_tmp_dir ();
+    const gchar      *username = g_get_user_name ();
+    const gchar      *basename = g_get_prgname ();
+
+    gchar progress_string[GPIV_MAX_CHARS];
+
+    /*
+     * Save image at tmp directory
+     */
+    gchar            *image_name = 
+        g_strdup_printf ("%s/%s__%s%s" , tmp_dir, basename, username,
+                         GPIV_EXT_PNG_IMAGE);
+    gchar            *pivdata_name =
+        g_strdup_printf ("%s/%s__%s%s" , tmp_dir, basename, username,
+                         GPIV_EXT_PIV);
+    gchar            *par_name =
+        g_strdup_printf ("%s/%s__%s%s" , tmp_dir, basename, username,
+                         GPIV_EXT_PAR);
+
+/*
+ * prints to message console bar
+ */
+    g_snprintf (progress_string, GPIV_MAX_CHARS, 
+                "Interrogating image #%d using %s %d gpiv_rr",
+                display_act->id, MPIRUN_CMD, gpiv_par->mpi_nodes);
+    gnome_appbar_set_status (GNOME_APPBAR(gpiv->appbar), 
+                             progress_string);
+/*     gtk_progress_set_value (GTK_PULSE? (gnome_appbar_get_progress */
+/*                                           (GNOME_APPBAR (gpiv->appbar))),  */
+/*                             progress_value); */
+
+    if (gpiv_par->verbose) g_message ("exec_piv_mpi: image name = %s, piv name = %s", 
+               image_name, pivdata_name);
+
+   if ((fp = fopen (image_name, "wb")) == NULL) {
+        error_gpiv ("exec_piv_mpi: failing fopen %s\n probably user directory under %s does not exist", tmp_dir, image_name);
+    }
+    gpiv_write_png_image (fp, image, FALSE);
+    fclose (fp);
+
+    /* 
+     * Run MPI-paralellised gpiv_rr
+     */
+    command = 
+        g_strdup_printf ("%s %d gpiv_rr -p \
+--cf %d --cl %d --cp %d \
+--rf %d --rl %d --rp %d \
+--ia_size_i %d --ia_size_f %d \
+--ia_shift %d --ischeme %d \
+--ifit %d --peak %d \
+--val_r %d --val_s %d --val_t %f", 
+                         MPIRUN_CMD, gpiv_par->mpi_nodes,
+                         piv_par->col_start, piv_par->col_end, piv_par->pre_shift_col, 
+                         piv_par->row_start, piv_par->row_end, piv_par->pre_shift_row,
+                         piv_par->int_size_i, piv_par->int_size_f, 
+                         piv_par->int_shift, piv_par->int_scheme, 
+                         piv_par->ifit, piv_par->peak, 
+                         valid_par->residu_type, valid_par->subst_type, valid_par->residu_max);
+
+    if (piv_par->spof_filter) {
+        command = g_strconcat (command, " --spof", NULL);
+    }
+    if (gpiv_par->verbose) {
+        command = g_strconcat (command, " -p", NULL);
+    }
+    command = g_strconcat (command, " ", image_name, NULL);
+    if (gpiv_par->verbose) g_message ("exec_piv_mpi: command = %s", command);
+
+    if (system (command) != 0) {
+        error_gpiv ("exec_piv_mpi: could not exec shell command:\n %s", command);
+    }
+    g_free (command);
+
+    /*
+     * Obtain PIV-data from tmp/
+     */
+    pd = gpiv_fread_pivdata(pivdata_name);
+
+    /*
+     * Cleanup image and data from tmp/
+     */
+    command = g_strdup_printf ("rm %s %s %s", image_name, pivdata_name, par_name);
+    if (system (command) != 0) {
+        error_gpiv ("exec_piv_mpi: could not exec shell command:\n %s", command);
+    }
+
+    g_free (command);
+    g_free (image_name);
+    g_free (pivdata_name);
+    g_free (par_name);
+    return pd;
+}
+#endif /* ENABLE_MPI */
