@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of gpiv.
 
@@ -27,6 +28,12 @@
 
 /*
  * $Log: preferences.c,v $
+ * Revision 1.18  2008-10-09 14:43:37  gerber
+ * paralellized with OMP and MPI
+ *
+ * Revision 1.17  2008-04-28 12:00:58  gerber
+ * hdf-formatted files are now with .hdf extension (previously: .gpi)
+ *
  * Revision 1.16  2007-12-19 08:42:35  gerber
  * debugged
  *
@@ -423,6 +430,19 @@ on_spinbutton_bins_activate(GtkWidget *widget,
 
 
 
+#ifdef ENABLE_MPI
+void 
+on_spinbutton_nodes(GtkSpinButton *widget, 
+                    GtkWidget *entry
+                    )
+/*-----------------------------------------------------------------------------
+ */
+{
+    default_par->mpi_nodes = gtk_spin_button_get_value_as_int (widget);
+}
+#endif
+
+
 void
 on_radiobutton_display_vecscale(GtkWidget *widget, 
                                      gpointer data
@@ -870,9 +890,11 @@ store_defaultpar (void
     gnome_config_set_bool ("console__view_gpivbuttons", default_par->console__view_gpivbuttons);
     gnome_config_set_bool ("console__view_tabulator", default_par->console__view_tabulator);
     gnome_config_set_int ("console__nbins", default_par->console__nbins);
-
     gnome_config_set_bool ("img_fmt", default_par->img_fmt);
     gnome_config_set_bool ("hdf", default_par->hdf);
+#ifdef ENABLE_MPI
+    gnome_config_set_int ("mpi_nodes", default_par->mpi_nodes);
+#endif /* ENABLE_MPI */
 
 
     gnome_config_pop_prefix ();
@@ -915,6 +937,7 @@ store_defaultpar (void
     gnome_config_set_bool ("display__piv", default_par->display__piv);
     gnome_config_set_int ("display__scalar", default_par->display__scalar);
     
+
     gnome_config_pop_prefix ();
     gnome_config_sync ();
 
