@@ -3,7 +3,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 
+   Gerber van der Graaf <gerber_graaf@users.sourceforge.net>
 
    This file is part of gpiv.
 
@@ -25,6 +26,9 @@
 
 /*
  * $Log: preferences.h,v $
+ * Revision 1.13  2008-10-09 14:43:37  gerber
+ * paralellized with OMP and MPI
+ *
  * Revision 1.12  2007-12-19 08:42:35  gerber
  * debugged
  *
@@ -171,7 +175,11 @@ void
 on_spinbutton_bins_activate (GtkWidget *widget, 
 			     gpointer data);
 
-
+#ifdef ENABLE_MPI
+void
+on_spinbutton_nodes (GtkSpinButton *widget, 
+		     GtkWidget *entry);
+#endif /* ENABLE_MPI */
 
 void
 on_radiobutton_display_zoomscale (GtkWidget *widget, 
