@@ -3,7 +3,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 
+   Gerber van der Graaf <gerber_graaf@users.sourceforge.net>
 
    This file is part of gpiv.
 
@@ -24,7 +25,13 @@
 ----------------------------------------------------------------------*/
 
 /*
- * $Log: $
+ * $Log: preferences_interface.h,v $
+ * Revision 1.2  2008-10-09 14:43:37  gerber
+ * paralellized with OMP and MPI
+ *
+ * Revision 1.1  2008-09-16 11:23:03  gerber
+ * added preferences_interface
+ *
  */
 
 #ifndef PREFERENCES_INTERFACE_H
@@ -85,7 +92,12 @@ struct _Pref {
     GtkWidget *label_spinner_bins;
     GtkObject *spinbutton_bins_adj;
     GtkWidget *spinbutton_bins;
-    
+#ifdef ENABLE_MPI
+    GtkWidget *hbox2;
+    GtkWidget *label_spinner_nodes;
+    GtkObject *spinbutton_nodes_adj;
+    GtkWidget *spinbutton_nodes;
+#endif /* ENABLE_MPI */
 
 
     GtkWidget *tab1;
