@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002, 2003, 2004 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of gpiv.
 
@@ -27,6 +28,9 @@
 
 /*
  * $Log: print.c,v $
+ * Revision 1.9  2008-04-28 12:00:58  gerber
+ * hdf-formatted files are now with .hdf extension (previously: .gpi)
+ *
  * Revision 1.8  2007-11-23 16:24:08  gerber
  * release 0.5.0: Kafka
  *
