@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of gpiv.
 
@@ -28,6 +29,9 @@
 /*
  * utility functions for gpiv
  * $Log: utils.c,v $
+ * Revision 1.22  2008-04-28 12:00:58  gerber
+ * hdf-formatted files are now with .hdf extension (previously: .gpi)
+ *
  * Revision 1.21  2007-12-19 08:42:35  gerber
  * debugged
  *
