@@ -5,7 +5,8 @@
   gpiv - Graphic program for Particle Image Velocimetry, based on gtk/gnome
           libraries.
 
-   Copyright (C) 2002 Gerber van der Graaf
+   Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008
+   Gerber van der Graaf
 
    This file is part of gpiv.
 
@@ -27,7 +28,13 @@
 
 /*
  * utility functions for gpiv
- * $Log: $
+ * $Log: utils_par.c,v $
+ * Revision 1.2  2008-10-09 14:43:37  gerber
+ * paralellized with OMP and MPI
+ *
+ * Revision 1.1  2008-09-16 11:24:37  gerber
+ * added utils_par
+ *
  *
  */
 
@@ -117,6 +124,11 @@ parameters_set (Par *par,
     par->display__intregs = bool;    
     par->display__piv = bool;    
     par->display__scalar__set = bool; 
+
+#ifdef ENABLE_MPI
+    par->mpi_nodes__set = bool;
+#endif /* ENABLE_MPI */
+
 }
 
 
@@ -274,7 +286,12 @@ set_parameters_ifdiff (Par *par_src,
                       (int *) &par_dest->display__scalar, 
                       &par_dest->display__scalar__set);
 
-    
+#ifdef ENABLE_MPI
+  set_par_int_ifdiff (&par_src->mpi_nodes, 
+		      &par_dest->mpi_nodes, 
+		      &par_dest->mpi_nodes__set);
+#endif /* ENABLE_MPI */
+
 }
 
 
@@ -399,7 +416,11 @@ print_parameters (Par *par
     print_par_bool ("display__scalar", par->display__scalar, 
                     par->display__scalar__set);
 
-    
+#ifdef ENABLE_MPI
+    print_par_int ("mpi_nodes", par->mpi_nodes, 
+                   par->mpi_nodes__set);
+
+#endif /* ENABLE_MPI */    
 }
 
 
@@ -791,5 +812,13 @@ par_ovwrt_parameters (Par *par_src,
         par_dest->display__scalar__set = TRUE;
     }
 
+#ifdef ENABLE_MPI
+    if (force 
+        || ( par_src->mpi_nodes__set 
+             && !par_dest->mpi_nodes__set)) {
+        par_dest->mpi_nodes = par_src->mpi_nodes;
+        par_dest->mpi_nodes__set = TRUE;
+    }
+#endif /* ENABLE_MPI */
 
 }
